@@ -1,8 +1,5 @@
 import aiofiles
 import glob
-import logging
-
-log = logging.getLogger(__name__)
 
 
 async def load_disks(hub):
@@ -17,12 +14,12 @@ async def load_disks(hub):
             flag = await entry_fp.read(1)
             if flag == "0":
                 SSDs.append(device)
-                log.debug(f"Device {device} reports itself as an SSD")
+                hub.log.debug(f"Device {device} reports itself as an SSD")
             elif flag == "1":
                 disks.append(device)
-                log.debug(f"Device {device} reports itself as an HDD")
+                hub.log.debug(f"Device {device} reports itself as an HDD")
             else:
-                log.error(
+                hub.log.error(
                     f"Unable to identify device {device} as an SSD or HDD. It does not report 0 or 1"
                 )
     if SSDs:
