@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 import asyncio
+import dict_tools
 import functools
 import os
 import shlex
@@ -126,11 +127,19 @@ async def run(
 
             .. code-block:: bash
 
-                salt myminion cmd.run 'some command' env='{"FOO": "bar"}'
+                idem exec cmd.run 'some command' env='{"FOO": "bar"}'
     :param umask: The umask (in octal) to use when running the command.
 
     :param timeout: A timeout in seconds for the executed process to return.
+
+    CLI Example:
+
+    .. code-block:: bash
+
+        idem exec cmd.run "command" cwd=/home
     """
+    ret = dict_tools.data.NamespaceDict()
+
     cmd = await _sanitize_cmd(hub, cmd)
     cwd = await _sanitize_cwd(hub, cwd)
     env = await _sanitize_env(hub, env)
@@ -151,15 +160,12 @@ async def run(
         proc = await asyncio.create_subprocess_shell(" ".join(cmd), **new_kwargs)
     else:
         proc = await asyncio.create_subprocess_exec(*cmd, **new_kwargs)
+    ret.pid = proc.pid
 
     # This is where the magic happens
     out, err = await asyncio.wait_for(proc.communicate(input=stdin), timeout=timeout)
-    # TODO do a wrapper around a dict that makes it namespace addressable
-    return hub.pop.data.imap(
-        {
-            "pid": proc.pid,
-            "retcode": await asyncio.wait_for(proc.wait(), timeout=timeout),
-            "stdout": (out or b"").decode(),
-            "stderr": (err or b"").decode(),
-        }
-    )
+
+    ret.stdout = (out or b"").decode()
+    ret.stderr = (err or b"").decode()
+    ret.retcode = await asyncio.wait_for(proc.wait(), timeout=timeout)
+    return ret
