@@ -24,7 +24,7 @@ __virtualname__ = "smbios"
 
 
 async def _dmi_data(
-    dmi_raw, clean: bool, fields: str
+    hub, dmi_raw, clean: bool, fields: str
 ) -> Dict[str, List[int or List[int]]]:
     """
     Parse the raw DMIdecode output of a single handle
@@ -59,7 +59,7 @@ async def _dmi_data(
                 key = None
                 continue
             else:
-                key_data = [await _dmi_cast(key, val.strip(), clean), []]
+                key_data = [await _dmi_cast(hub, key, val.strip(), clean), []]
         elif key is None:
             continue
         elif re.match(r"\t\t[^\s]+", line):
@@ -68,7 +68,7 @@ async def _dmi_data(
             # Characteristics:
             #        PCI is supported
             #        PNP is supported
-            val = await _dmi_cast(key, line.strip(), clean)
+            val = await _dmi_cast(hub, key, line.strip(), clean)
             if val is not None:
                 hub.log.debug(f"DMI key {key} gained list item {val}")
                 key_data[1].append(val)
@@ -77,7 +77,7 @@ async def _dmi_data(
 
 
 async def _dmi_parse(
-    data, clean: bool = True, fields: str = None
+    hub, data, clean: bool = True, fields: str = None
 ) -> List[Dict[str, Any]]:
     """
     Structurize DMI records into a nice list
@@ -109,7 +109,7 @@ async def _dmi_parse(
             continue
 
         hub.log.debug(f"{record} record contains {dmi_raw}")
-        dmi_data = await _dmi_data(dmi_raw, clean, fields)
+        dmi_data = await _dmi_data(hub, dmi_raw, clean, fields)
         if dmi_data:
             record["data"] = dmi_data
             dmi.append(record)
@@ -119,11 +119,11 @@ async def _dmi_parse(
     return dmi
 
 
-async def _dmi_cast(key: str, val, clean=True) -> int or None:
+async def _dmi_cast(hub, key: str, val, clean=True) -> int or None:
     """
     Simple caster thingy for trying to fish out at least ints & lists from strings
     """
-    if clean and not await _dmi_isclean(key, val):
+    if clean and not await _dmi_isclean(hub, key, val):
         return
     elif not re.match(r"serial|part|asset|product", key, flags=re.IGNORECASE):
         if "," in val:
@@ -137,7 +137,7 @@ async def _dmi_cast(key: str, val, clean=True) -> int or None:
     return val
 
 
-async def _dmi_isclean(key: str, val: str or None) -> bool:
+async def _dmi_isclean(hub, key: str, val: str or None) -> bool:
     """
     Clean out well-known bogus values
     """
@@ -324,4 +324,4 @@ async def records(
     if isinstance(fields, list):
         fields = ",".join([f.strip() for f in fields])
 
-    return await _dmi_parse((await _dmi_decode(hub, args)), clean, fields)
+    return await _dmi_parse(hub, (await _dmi_decode(hub, args)), clean, fields)
